@@ -1,6 +1,6 @@
 /******************************************************************************\
- * $Id: builderDirs2.cpp,v 1.4 2001/05/22 07:30:19 blais Exp $
- * $Date: 2001/05/22 07:30:19 $
+ * $Id: builderDirs2.cpp,v 1.5 2001/05/28 18:32:02 blais Exp $
+ * $Date: 2001/05/28 18:32:02 $
  *
  * Copyright (C) 1999-2001  Martin Blais <blais@iro.umontreal.ca>
  *
@@ -64,7 +64,7 @@ enum DirDiffType {
 };
 
 #ifdef LOCAL_TRACE
-char* typeString[4] = { 
+char* typeString[5] = { 
    "IDENTICAL", "DIFFER", "ONLY_IN", "UNKNOWN", "COMMON_SUBDIR"
 };
 #endif
@@ -373,7 +373,7 @@ void buildSolelyFromOutput(
       }
 
 #ifdef LOCAL_TRACE
-      std::cout << buffer << std::endl;
+      std::cout << buffer;
       std::cout << typeString[ type ] << "   " 
                 << filename << "   "
                 << onlyDir << std::endl;
@@ -456,7 +456,7 @@ void buildAgainstReadDirectory(
       }
 
 #ifdef LOCAL_TRACE
-      std::cout << buffer << std::endl;
+      std::cout << buffer;
       std::cout << typeString[ type ] << "   " 
                 << filename << "   "
                 << onlyDir << std::endl;
