@@ -1,6 +1,6 @@
 /******************************************************************************\
- * $Id: markersFileDialog.cpp,v 1.4 2001/05/28 02:17:42 blais Exp $
- * $Date: 2001/05/28 02:17:42 $
+ * $Id: markersFileDialog.cpp,v 1.5 2001/07/07 19:41:03 blais Exp $
+ * $Date: 2001/07/07 19:41:03 $
  *
  * Copyright (C) 1999-2001  Martin Blais <blais@iro.umontreal.ca>
  *
@@ -159,6 +159,7 @@ QString XxMarkersFileDialog::getSaveFileName(
    const QString& startWith,
    const QString& filter,
    QWidget*       parent,
+   const char*    name,
    bool           threeWay,
    bool&          useConditionals,
    bool&          removeEmptyConditionals,
@@ -184,7 +185,7 @@ QString XxMarkersFileDialog::getSaveFileName(
 
 
    XxMarkersFileDialog* dlg = new XxMarkersFileDialog(
-      startWith, filter, parent, QString::null, TRUE, threeWay
+      startWith, filter, parent, name, TRUE, threeWay
    );
    CHECK_PTR( dlg );
    dlg->setCaption( QFileDialog::tr( "Save as" ) );
