@@ -1,6 +1,6 @@
 /******************************************************************************\
- * $Id: optionsDialog.cpp,v 1.10 2001/05/20 18:08:45 blais Exp $
- * $Date: 2001/05/20 18:08:45 $
+ * $Id: optionsDialog.cpp,v 1.13 2001/06/04 20:16:12 blais Exp $
+ * $Date: 2001/06/04 20:16:12 $
  *
  * Copyright (C) 1999-2001  Martin Blais <blais@iro.umontreal.ca>
  *
@@ -40,6 +40,7 @@
 #include <qcolor.h>
 #include <qcolordialog.h>
 #include <qlabel.h>
+#include <qcombobox.h>
 
 #include <map>
 
@@ -173,10 +174,16 @@ XxOptionsDialog::XxOptionsDialog(
             this, SLOT( checkboxHideCarriageReturns(int) ) );
    connect( _spinboxTabWidth, SIGNAL( valueChanged(int) ), 
             this, SLOT( spinboxTabWidth(int) ) );
+   connect( _checkboxDrawVerticalLine, SIGNAL( stateChanged(int) ), 
+            this, SLOT( checkboxDrawVerticalLine(int) ) );
+   connect( _comboIgnoreFile, SIGNAL( textChanged(const QString&) ), 
+            this, SLOT( comboIgnoreFile(const QString&) ) );
+
    connect( _checkboxIgnoreFileChanges, SIGNAL( stateChanged(int) ), 
             this, SLOT( checkboxIgnoreFileChanges(int) ) );
-   connect( _checkboxCutAndPasteAnnotations, SIGNAL( stateChanged(int) ), 
-            this, SLOT( checkboxCutAndPasteAnnotations(int) ) );
+
+   connect( _checkboxFormatClipboardText, SIGNAL( stateChanged(int) ),
+            this, SLOT( checkboxFormatClipboardText(int) ) );
 
    //---------------------------------------------------------------------------
    // Colors
@@ -307,11 +314,23 @@ void XxOptionsDialog::synchronize()
 
    _spinboxTabWidth->setValue( resources->getTabWidth() );
 
+   _checkboxDrawVerticalLine->setChecked(
+      resources->getBoolOpt( XxResources::SHOW_VERTICAL_LINE )
+   );
+
+   _comboIgnoreFile->setCurrentItem( int( resources->getIgnoreFile() ) );
+
+
    _checkboxIgnoreFileChanges->setChecked(
       resources->getBoolOpt( XxResources::DIRDIFF_IGNORE_FILE_CHANGES )
    );
-   _checkboxCutAndPasteAnnotations->setChecked(
-      resources->getBoolOpt( XxResources::CUT_AND_PASTE_ANNOTATIONS )
+
+   _checkboxFormatClipboardText->setChecked(
+      resources->getBoolOpt( XxResources::FORMAT_CLIPBOARD_TEXT )
+   );
+
+   _lineeditClipboardTextFormat->setText(
+      QString( resources->getClipboardTextFormat().c_str() )
    );
 
    //---------------------------------------------------------------------------
@@ -401,14 +420,29 @@ void XxOptionsDialog::onApply()
 
    resources->setTabWidth( _spinboxTabWidth->value() );
 
+   resources->setBoolOpt( XxResources::SHOW_VERTICAL_LINE, 
+                          _checkboxDrawVerticalLine->isChecked() );
+
+   resources->setVerticalLinePos( _spinboxVlinePos->value() );
+
+   resources->setIgnoreFile(
+      XxResources::IgnoreFile(_comboIgnoreFile->currentItem())
+   );
+
    resources->setBoolOpt( XxResources::DIRDIFF_IGNORE_FILE_CHANGES, 
                           _checkboxIgnoreFileChanges->isChecked() );
    if ( _checkboxIgnoreFileChanges->isChecked() == true ) {
       redoDiff = true;
    }
 
-   resources->setBoolOpt( XxResources::CUT_AND_PASTE_ANNOTATIONS, 
-                          _checkboxCutAndPasteAnnotations->isChecked() );
+   resources->setBoolOpt( XxResources::FORMAT_CLIPBOARD_TEXT, 
+                          _checkboxFormatClipboardText->isChecked() );
+
+   std::string oldClipboardFormat = resources->getClipboardTextFormat();
+   const char* newClipboardFormat = _lineeditCommandFiles2->text().ascii();
+   if ( ::strcmp( newClipboardFormat, oldClipboardFormat.c_str() ) != 0 ) {
+      resources->setClipboardTextFormat( newClipboardFormat );
+   }
 
    //---------------------------------------------------------------------------
    // Colors
@@ -604,7 +638,21 @@ void XxOptionsDialog::checkboxIgnoreFileChanges( int state )
 
 //------------------------------------------------------------------------------
 //
-void XxOptionsDialog::checkboxCutAndPasteAnnotations( int state )
+void XxOptionsDialog::checkboxFormatClipboardText( int state )
+{
+   // nop.
+}
+
+//------------------------------------------------------------------------------
+//
+void XxOptionsDialog::checkboxDrawVerticalLine( int state )
+{
+   // nop.
+}
+
+//------------------------------------------------------------------------------
+//
+void XxOptionsDialog::comboIgnoreFile( const QString& )
 {
    // nop.
 }
