@@ -1,6 +1,6 @@
 /******************************************************************************\
- * $Id: util.cpp,v 1.13 2001/06/04 05:08:52 blais Exp $
- * $Date: 2001/06/04 05:08:52 $
+ * $Id: util.cpp,v 1.17 2001/06/27 01:57:08 blais Exp $
+ * $Date: 2001/06/27 01:57:08 $
  *
  * Copyright (C) 1999-2001  Martin Blais <blais@iro.umontreal.ca>
  *
@@ -28,6 +28,9 @@
 #include <exceptions.h>
 #include <main.h>
 
+#include <qstring.h>
+#include <qtextstream.h>
+
 #include <sstream>
 #include <iostream>
 #include <sys/types.h>
@@ -187,9 +190,10 @@ bool XxUtil::testFile(
    
    // Check for access.
    if ( access( filename, R_OK ) != 0 ) {
-      std::ostringstream oss;
-      oss << "Cannot access file: " << filename << std::ends;
-      throw new XxIoError( oss.str().c_str() );
+      QString s;
+      QTextOStream oss( & s );
+      oss << "Cannot access file: " << filename;
+      throw new XxIoError( s.latin1() );
    }
 
    // Stat file.
@@ -276,7 +280,7 @@ bool XxUtil::spawnCommand(
       }
 
       default: {
-         if ( sigaction != 0 ) {
+         if ( sigChldHandler != 0 ) {
             XX_TRACE( "Installing SIGCHLD handler." );
 
             // sigset_t spm_o;
@@ -436,4 +440,18 @@ void XxUtil::printTime( std::ostream& os, long time )
    os << "sec.usec=" << tv_sec << "." << tv_usec << std::endl;
 }
 
+//------------------------------------------------------------------------------
+//
+void XxUtil::TESTQTSTREAMS() const
+{
+   QString s;
+   QTextOStream oss( & s );
+   oss << "Cannot access file: " << "gugu";
+
+   std::cout << s.latin1();
+
+
+}
+
 XX_NAMESPACE_END
+
