@@ -1,6 +1,6 @@
 /******************************************************************************\
- * $Id: util.h,v 1.11 2001/06/04 20:16:12 blais Exp $
- * $Date: 2001/06/04 20:16:12 $
+ * $Id: util.h,v 1.12 2001/06/18 03:17:30 blais Exp $
+ * $Date: 2001/06/18 03:17:30 $
  *
  * Copyright (C) 1999-2001  Martin Blais <blais@iro.umontreal.ca>
  *
@@ -113,6 +113,9 @@ public:
    // Print time value to stream.
    static void printTime( std::ostream& os, long time );
 
+   // FIXME remove
+   void TESTQTSTREAMS() const;
+
 };
 
 
